"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createBaseConfig = void 0;
const webpack_1 = __importDefault(require("webpack"));
const path = __importStar(require("path"));
const certificateManager = require('@rushstack/debug-certificate-manager');
const certificateStore = new certificateManager.CertificateStore();
const fork_ts_checker_webpack_plugin_1 = __importDefault(require("fork-ts-checker-webpack-plugin"));
const ClearCssModuleDefinitionsPlugin_1 = require("../plugins/ClearCssModuleDefinitionsPlugin");
const helpers_1 = require("./helpers");
const packageJson = helpers_1.getJSONFile('package.json');
const hasESLint = !!packageJson.devDependencies['@typescript-eslint/parser'];
const rootFolder = path.resolve(process.cwd());
function createBaseConfig(settings) {
    const port = settings.cli.isLibraryComponent ? 4320 : 4321;
    const host = 'https://localhost:' + port;
    const cssLoader = require.resolve('css-loader');
    const themedLoader = require.resolve('@microsoft/loader-load-themed-styles');
    const baseConfig = {
        target: 'web',
        mode: 'development',
        devtool: 'source-map',
        resolve: {
            extensions: ['.ts', '.tsx', '.js'],
            modules: ['node_modules']
        },
        context: rootFolder,
        module: {
            rules: [
                {
                    test: /\.tsx?$/,
                    loader: require.resolve('ts-loader'),
                    options: {
                        transpileOnly: true,
                        compilerOptions: {
                            declarationMap: false
                        }
                    },
                    exclude: /node_modules/
                },
                {
                    use: [{
                            loader: require.resolve('file-loader'),
                            options: {
                                name: '[name]_[hash].[ext]',
                                esModule: false
                            }
                        }],
                    test: /\.(jpe?g|png|woff|eot|ttf|svg|gif|dds)$/i
                },
                {
                    use: [{
                            loader: 'html-loader'
                        }],
                    test: /\.html$/
                },
                {
                    test: /\.css$/,
                    use: [
                        {
                            loader: themedLoader,
                            options: {
                                async: true
                            }
                        },
                        {
                            loader: cssLoader,
                            options: {
                                esModule: false,
                                modules: false
                            }
                        }
                    ]
                },
                {
                    test: function (fileName) {
                        return fileName.endsWith('.module.scss');
                    },
                    use: [
                        {
                            loader: themedLoader,
                            options: {
                                async: true
                            }
                        },
                        require.resolve('spfx-css-modules-typescript-loader'),
                        {
                            loader: cssLoader,
                            options: {
                                esModule: false,
                                modules: {
                                    localIdentName: '[local]_[hash:base64:8]'
                                }
                            }
                        },
                        require.resolve('sass-loader')
                    ]
                },
                {
                    test: function (fileName) {
                        return !fileName.endsWith('.module.scss') && fileName.endsWith('.scss');
                    },
                    use: [
                        {
                            loader: themedLoader,
                            options: {
                                async: true
                            }
                        },
                        {
                            loader: cssLoader,
                            options: {
                                esModule: false,
                                modules: false
                            }
                        },
                        require.resolve('sass-loader')
                    ]
                }
            ]
        },
        plugins: [
            new fork_ts_checker_webpack_plugin_1.default({
                eslint: hasESLint ? {
                    files: './src/**/*.{ts,tsx}',
                    enabled: true
                } : undefined,
                async: true
            }),
            new ClearCssModuleDefinitionsPlugin_1.ClearCssModuleDefinitionsPlugin({
                deleted: false,
                rootFolder
            }),
            new webpack_1.default.DefinePlugin({
                'process.env.NODE_ENV': JSON.stringify(process.env.NODE_ENV),
                'process.env.DEBUG': JSON.stringify(true),
                'DEBUG': JSON.stringify(true)
            })
        ],
        devServer: {
            hot: false,
            contentBase: rootFolder,
            publicPath: host + '/dist/',
            host: 'localhost',
            port: port,
            disableHostCheck: true,
            historyApiFallback: true,
            open: settings.serve.open,
            writeToDisk: settings.cli.isLibraryComponent,
            openPage: settings.serve.openUrl ? settings.serve.openUrl : host + '/temp/workbench.html',
            overlay: settings.serve.fullScreenErrors,
            stats: helpers_1.getLoggingLevel(settings.serve.loggingLevel),
            headers: {
                'Access-Control-Allow-Origin': '*',
            },
            https: {
                cert: certificateStore.certificateData,
                key: certificateStore.keyData
            }
        },
    };
    return baseConfig;
}
exports.createBaseConfig = createBaseConfig;
//# sourceMappingURL=baseConfig.js.map